# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['leximpact_prepare_data']

package_data = \
{'': ['*']}

install_requires = \
['OpenFisca-France-Data>=0.21,<0.22',
 'OpenFisca-France>=113.0.4,<114.0.0',
 'OpenFisca-Survey-Manager[pipeline]==0.46.13',
 'leximpact-aggregates>=0.0.15,<0.0.16',
 'leximpact-socio-fisca-simu-etat>=0.1.2,<0.2.0',
 'multipledispatch>=0.6.0,<0.7.0',
 'nbdev>=2.2.10,<3.0.0',
 'pandas>=1.3.0,<2.0.0',
 'pyarrow==6.0.1',
 'typing-extensions>=3.10.0,<4.0.0',
 'vaex-jupyter>=0.7.0,<0.8.0',
 'vaex-server>=0.8.1,<0.9.0',
 'xarray==2022.3.0']

extras_require = \
{':extra == "pipeline"': ['scikit-learn[pipeline]>=1.0.1,<2.0.0',
                          'diagrams[pipeline]>=0.20.0,<0.21.0',
                          'vaex-core[pipeline]>=4.8.0,<5.0.0',
                          'tables[pipeline]>=3.6.1,<4.0.0',
                          'python-dotenv[pipeline]>=0.19.2,<0.20.0']}

setup_kwargs = {
    'name': 'leximpact-prepare-data',
    'version': '0.0.28',
    'description': 'Prepare data for LexImpact',
    'long_description': 'Préparation des données pour LexImpact\n================\n\n<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->\n\nCe projet regroupe les scripts permettant de préparer les données des\ndifférents projets [Leximpact](https://leximpact.an.fr).\n\n## Schéma complet de préparation et d’utilisation des données\n\n![LexImpact Pipeline](schemas/leximpact_pipeline.png)\n\nLe pipeline prepare-data est donc le suivant :\n\nInput: erfs_flat_2018.h5\n\n### 01_db_reduce.ipynb\n\nObjectif: Réduit le nombre de variables dans la base\n\nOutput: 01_erfs_reduced_2018.h5\n\n### 02_db_enlarge.ipynb\n\nObjectif: Ajoute des gens fictifs dans la base pour pouvoir calibrer\n\nOutput: 02_erfs_enlarged_2018.h5\n\n### 03_db_add_rfr.ipynb\n\nInput : CalibPote-2018-revkire.json\n\nObjectifs: - Calculer le RFR dans OpenFisca - Calibrer le RFR ERFS_2018\nsur POTE_2018\n\nOutput: 03_erfs_rfr_2018.h5\n\n### 04_db_add_var\n\n0403_db_add_var_copules.ipynb\n\n0401_db_add_var_copules-algo_monte-carlo.ipynb\n\n0402_db_add_var_copules-validate.ipynb\n\nInput : ExportCopule-2018-variable.json\n\nObjectif: Ajoute les variables issues de POTE 2018 dans la base ERFS\n2018\n\nOutput: 04_erfs_var_copules_2018.h5\n\n### 05_db_calib_var_copules.ipynb\n\nInput : CalibPote-2019-variable.json\n\nObjectifs: - Vieillit la base ERFS_2018 vers 2019 (nos données les plus\nrécentes) : inflation économique et inflation des foyers - Calibre\nchacune des variables issues de POTE sur POTE 2019\n\nOutput: 05_erfs_calibrated_ff_2018_to_2019.h5\n\n### 06_db_aging_final.ipynb\n\nObjectifs:\n\n- Vieillit la base ERFS_2019 vers 2021 (année voulue pour les calculs) :\n  inflation économique et inflation des foyers\n- Bruitage statistique de la base pour anonymisation\n\nOutput: 06_erfs_ff_2018_aged_2021.h5\n\n# How to contribute\n\nPlease see the [contributing\npage](https://documentation.leximpact.dev/leximpact_prepare_data/contributing).\n',
    'author': 'LexImpact',
    'author_email': 'leximpact@an.fr',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://leximpact.an.fr/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
